OC.L10N.register(
    "bookmarks",
    {
    "Details" : "معلومات",
    "Rename" : "نوم بدلول",
    "Move" : "انتقال",
    "Delete" : "ړنګول",
    "Select all" : "ټول ټاکل",
    "New" : "نوی",
    "New folder" : "نوی فولډر",
    "Cancel" : "پرېښول",
    "Recent" : "وروستي",
    "Link" : "لېنک",
    "Tags" : "نښکې",
    "Notes" : "شسیب",
    "Share link" : "د شرېکېدو لېنک",
    "Copy link" : "لېنک کاپي کول",
    "Allow editing" : "د سمون اجازه ورکول",
    "Save" : "ساتل"
},
"nplurals=2; plural=(n != 1);");
